@@ -109,7 +109,7 @@ class Machine():
         if self._zones == {}:
             self.discover_zones()
         for zone in self._zones.values():
-            zone.retrieve_zone_status()
+            zone.retrieve_zone_state()
 
     @property            
     def zones(self):
@@ -463,7 +463,7 @@ class Zone():
 
     @property
     def dif_current_temp(self):
-        return self.signal_temperature_value - self.local_temperature()
+        return self.signal_temperature_value - self.local_temperature
     
     @deprecated('use property')
     def get_dif_current_temp(self):
